==> calendar-v1.7.20.zip: calendar/messages/sr/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Dodaj</strong> profilni kalendar',
    '<strong>Choose</strong> target calendar' => '<strong>Odaberite</strong> ciljani kalendar',
    '<strong>Reminder</strong> settings' => 'Postavke <strong>podsetnika</strong>',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Dodavaje kalendara za privatne ili javne događaje na vaš profil i glavni meni.',
    'Adds an event calendar to this space.' => 'Dodaje kalendar događaja u ovaj prostor.',
    'After (occurrences)' => 'Nakon (pojave)',
    'All Day' => 'Celi dan',
    'Allows the user to create new calendar entries' => 'Korisniku omogućuje stvaranje novih unosa u kalendar',
    'Allows the user to edit/delete existing calendar entries' => 'Korisniku omogućuje uređivanje / brisanje postojećih unosa u kalendar',
    'Attending' => 'Prisustvuju',
    'Birthday' => 'Rođendan',
    'Calendar' => 'Kalendar',
    'Cancel Event' => 'Otkaži događaj',
    'Create entry' => 'Kreriaj unos',
    'Custom reminder' => 'Prilagođeni podsetnik',
    'Day' => 'Dan',
    'Days' => 'Dana',
    'Default reminder settings' => 'Podrazumevane postavke podsetnika',
    'Delete all events' => 'Izbriši sve događaje',
    'Deleted' => 'Obrisano',
    'Description' => 'Opis',
    'Do you want to install this module on your profile?' => 'Želite li instalirati ovaj modul na svoj profil?',
    'Edit' => 'Uredi',
    'Edit all events' => 'Uredi sve događaje',
    'Edit this and following events' => 'Uredite ovaj i sledeće događaje',
    'Edit this event' => 'Uredite ovaj događaj',
    'Email' => 'Email',
    'Enable' => 'Omogući',
    'End' => 'Završi',
    'End Date' => 'Datum završetka',
    'End Time' => 'Vreme završetka',
    'End time must be after start time!' => 'Vreme završetka mora biti nakon vremena početka!',
    'Event' => 'Događaj',
    'Event Type' => 'Tip događaja',
    'Event Types' => 'Vrste događaja',
    'Event not found!' => 'Događaj nije pronađen!',
    'Files' => 'Datoteke',
    'Friday' => 'Petak',
    'Here you can configure default settings for all calendar events.' => 'Ovde možete konfigurirati zadane postavke za sve kalendarske događaje.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Ovde možete konfigurirati globalne zadane podsetnike. Te se postavke mogu prebrisati na nivou prostora / profila.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Ovdje možete konfigurirati zadane postavke podsetnika za ovaj događaj. Korisnici su u mogućnosti da prepraviti ove postavke pomoću linka <strong>Podesi podsetnik</strong>.',
    'Hour' => 'Sat',
    'I\'m attending' => 'Ja prisustvujem',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Da biste dodali događaje u svoj profil, najprije morate omogućiti modul Kalendar.',
    'Interested' => 'Zainteresiran',
    'Invalid date or time format!' => 'Nevažeći format datuma ili vremena!',
    'Invalid day of month given' => 'Dat je nevažeći dan u mesecu',
    'Invalid event type id selected.' => 'Odabran je ID vrste vrste događaja koji nije valjan.',
    'Invalid frequency given' => 'Navedena je neispravna učestalost',
    'Invalid interval given' => 'Naveden je nevažeći interval',
    'Invalid week day selection' => 'Nevažeći odabir dana u nedelji',
    'Invite' => 'Poziv',
    'List' => 'Lista',
    'Location' => 'Lokacija',
    'Manage entries' => 'Upravljaj unosima',
    'Maximum number of participants' => 'Maksimalan broj učesnika',
    'Monday' => 'Ponedjeljak',
    'Month' => 'Mesec',
    'Monthly on day {dayOfMonth}' => 'Mesečno na dan {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Mesečno na {position} {dayOfWeek}',
    'Months' => 'Mjeseci',
    'Never' => 'Nikada',
    'Next' => 'Dalje',
    'No reminder' => 'Nema podsetnika',
    'On date' => 'Na datum',
    'Participants' => 'Učesnici',
    'Profile Calendar' => 'Profil Kalendar',
    'Public' => 'Javno',
    'Recurring' => 'Ponavljajući',
    'Reopen Event' => 'Ponovo otvori događaj',
    'Repeat every' => 'Ponovite svaki',
    'Saturday' => 'Subota',
    'Set reminder' => 'Postavi podsetnik',
    'Sorting' => 'Sortiraj',
    'Start Date' => 'Datum početka',
    'Start Time' => 'Vreme početka',
    'Sunday' => 'Nedjelja',
    'This event does not support recurrent events' => 'Ovaj događaj ne podržava ponavljajuće događaje',
    'Thursday' => 'Četvrtak',
    'Time Zone' => 'Vremenska zona',
    'Title' => 'Funkcija',
    'Today' => 'Danas',
    'Tuesday' => 'Utorak',
    'Upcoming {type}' => 'Predstojeći {type}',
    'Upcoming {type}: {title}' => 'Predstojeći {type}: {title}',
    'Use default reminder' => 'Upotrijebi podrazumevani podsetnik ',
    'User birthdays' => 'Rođendan korisnika',
    'Wednesday' => 'Sreda',
    'Week' => 'Sedemica',
    'Weeks' => 'Nedelja',
    'Year' => 'Godina',
    'Years' => 'Godine',
    'You don\'t have permission to delete this event!' => 'Nemate dozvolu da obrišete ovaj događaj!',
    'You have an <strong>{type}</strong> coming up' => 'Predstoji vam <strong>{type}</strong>',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Predstoji vam <strong>{type}</strong>: {title}',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Postavke podsetnika za događaj: <strong>\'{title}\'</strong>',
    'canceled' => 'otkazano',
    'disabled' => 'onemogućeno',
    'first' => 'prvi',
    'forth' => 'unaprijed',
    'last' => 'poslednji',
    'on weekdays' => 'radnim danima',
    'second' => 'drugi',
    'third' => 'treći',
    '{displayName} Birthday' => '{displayName} Rođendane',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vas je upravo dodao na događaj "{contentTitle}" u prostoru {spaceName} koji počinje {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} vas je upravo dodao na događaj "{contentTitle}".',
    'Add all Space members with status {status}' => '',
    'Add participants...' => '',
    'Added: {users}' => '',
    'Additional Information for participants' => '',
    'Allow option \'Decline\'' => '',
    'Allow option \'Undecided\'' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Cannot remove the participant!' => '',
    'Display events within the next X days' => '',
    'Download ICS' => '',
    'Edit Event' => '',
    'Enable Reminder' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Export as {type}' => '',
    'Filter by types' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'Invited: {users}' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Minute' => '',
    'Mode' => '',
    'No new participants were added.' => '',
    'No new participants were invited.' => '',
    'Notify participants about changes' => '',
    'Participant removed.' => '',
    'Participation Status' => '',
    'Please select new participants.' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Status cannot be updated.' => '',
    'Status updated.' => '',
    'The event has already ended.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'You cannot invite participants!' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} invited you to the event "{contentTitle}".' => '',
    '{name} Calendar' => '',
];

==> calendar-v1.8.4.zip: calendar/messages/sr/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Dodaj</strong> profilni kalendar',
    '<strong>Choose</strong> target calendar' => '<strong>Odaberite</strong> ciljani kalendar',
    '<strong>Reminder</strong> settings' => 'Postavke <strong>podsetnika</strong>',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Dodavaje kalendara za privatne ili javne događaje na vaš profil i glavni meni.',
    'Adds an event calendar to this space.' => 'Dodaje kalendar događaja u ovaj prostor.',
    'After (occurrences)' => 'Nakon (pojave)',
    'All Day' => 'Celi dan',
    'Allows the user to create new calendar entries' => 'Korisniku omogućuje stvaranje novih unosa u kalendar',
    'Allows the user to edit/delete existing calendar entries' => 'Korisniku omogućuje uređivanje / brisanje postojećih unosa u kalendar',
    'Attending' => 'Prisustvuju',
    'Birthday' => 'Rođendan',
    'Calendar' => 'Kalendar',
    'Cancel Event' => 'Otkaži događaj',
    'Create entry' => 'Kreriaj unos',
    'Custom reminder' => 'Prilagođeni podsetnik',
    'Day' => 'Dan',
    'Days' => 'Dana',
    'Default reminder settings' => 'Podrazumevane postavke podsetnika',
    'Delete all events' => 'Izbriši sve događaje',
    'Deleted' => 'Obrisano',
    'Description' => 'Opis',
    'Do you want to install this module on your profile?' => 'Želite li instalirati ovaj modul na svoj profil?',
    'Edit' => 'Uredi',
    'Edit all events' => 'Uredi sve događaje',
    'Edit this and following events' => 'Uredite ovaj i sledeće događaje',
    'Edit this event' => 'Uredite ovaj događaj',
    'Email' => 'Email',
    'Enable' => 'Omogući',
    'End' => 'Završi',
    'End Date' => 'Datum završetka',
    'End Time' => 'Vreme završetka',
    'End time must be after start time!' => 'Vreme završetka mora biti nakon vremena početka!',
    'Event' => 'Događaj',
    'Event Type' => 'Tip događaja',
    'Event Types' => 'Vrste događaja',
    'Event not found!' => 'Događaj nije pronađen!',
    'Files' => 'Datoteke',
    'Friday' => 'Petak',
    'Here you can configure default settings for all calendar events.' => 'Ovde možete konfigurirati zadane postavke za sve kalendarske događaje.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Ovde možete konfigurirati globalne zadane podsetnike. Te se postavke mogu prebrisati na nivou prostora / profila.',
    'Hour' => 'Sat',
    'I\'m attending' => 'Ja prisustvujem',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Da biste dodali događaje u svoj profil, najprije morate omogućiti modul Kalendar.',
    'Interested' => 'Zainteresiran',
    'Invalid date or time format!' => 'Nevažeći format datuma ili vremena!',
    'Invalid day of month given' => 'Dat je nevažeći dan u mesecu',
    'Invalid event type id selected.' => 'Odabran je ID vrste vrste događaja koji nije valjan.',
    'Invalid frequency given' => 'Navedena je neispravna učestalost',
    'Invalid interval given' => 'Naveden je nevažeći interval',
    'Invalid week day selection' => 'Nevažeći odabir dana u nedelji',
    'Invite' => 'Poziv',
    'List' => 'Lista',
    'Location' => 'Lokacija',
    'Manage entries' => 'Upravljaj unosima',
    'Maximum number of participants' => 'Maksimalan broj učesnika',
    'Monday' => 'Ponedjeljak',
    'Month' => 'Mesec',
    'Monthly on day {dayOfMonth}' => 'Mesečno na dan {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Mesečno na {position} {dayOfWeek}',
    'Months' => 'Mjeseci',
    'Never' => 'Nikada',
    'Next' => 'Dalje',
    'No reminder' => 'Nema podsetnika',
    'On date' => 'Na datum',
    'Participants' => 'Učesnici',
    'Profile Calendar' => 'Profil Kalendar',
    'Public' => 'Javno',
    'Recurring' => 'Ponavljajući',
    'Reopen Event' => 'Ponovo otvori događaj',
    'Repeat every' => 'Ponovite svaki',
    'Saturday' => 'Subota',
    'Set reminder' => 'Postavi podsetnik',
    'Sorting' => 'Sortiraj',
    'Start Date' => 'Datum početka',
    'Start Time' => 'Vreme početka',
    'Sunday' => 'Nedjelja',
    'This event does not support recurrent events' => 'Ovaj događaj ne podržava ponavljajuće događaje',
    'Thursday' => 'Četvrtak',
    'Time Zone' => 'Vremenska zona',
    'Title' => 'Funkcija',
    'Today' => 'Danas',
    'Tuesday' => 'Utorak',
    'Upcoming {type}' => 'Predstojeći {type}',
    'Upcoming {type}: {title}' => 'Predstojeći {type}: {title}',
    'Use default reminder' => 'Upotrijebi podrazumevani podsetnik ',
    'User birthdays' => 'Rođendan korisnika',
    'Wednesday' => 'Sreda',
    'Week' => 'Sedemica',
    'Weeks' => 'Nedelja',
    'Year' => 'Godina',
    'Years' => 'Godine',
    'You don\'t have permission to delete this event!' => 'Nemate dozvolu da obrišete ovaj događaj!',
    'You have an <strong>{type}</strong> coming up' => 'Predstoji vam <strong>{type}</strong>',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Predstoji vam <strong>{type}</strong>: {title}',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Postavke podsetnika za događaj: <strong>\'{title}\'</strong>',
    'canceled' => 'otkazano',
    'disabled' => 'onemogućeno',
    'first' => 'prvi',
    'forth' => 'unaprijed',
    'last' => 'poslednji',
    'on weekdays' => 'radnim danima',
    'second' => 'drugi',
    'third' => 'treći',
    '{displayName} Birthday' => '{displayName} Rođendane',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vas je upravo dodao na događaj "{contentTitle}" u prostoru {spaceName} koji počinje {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} vas je upravo dodao na događaj "{contentTitle}".',
    'Add all Space members with status {status}' => '',
    'Add participants...' => '',
    'Added: {users}' => '',
    'Additional Information for participants' => '',
    'Allow option \'Decline\'' => '',
    'Allow option \'Undecided\'' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Cannot remove the participant!' => '',
    'Display events within the next X days' => '',
    'Download ICS' => '',
    'Edit Event' => '',
    'Enable Reminder' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Export as {type}' => '',
    'Filter' => '',
    'Filter by types' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'Invited: {users}' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Minute' => '',
    'Mode' => '',
    'No new participants were added.' => '',
    'No new participants were invited.' => '',
    'Notify participants about changes' => '',
    'Participant removed.' => '',
    'Participation Status' => '',
    'Please select new participants.' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Status cannot be updated.' => '',
    'Status updated.' => '',
    'The event has already ended.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'You cannot invite participants!' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} invited you to the event "{contentTitle}".' => '',
    '{name} Calendar' => '',
];
